import react, { startTransition, useEffect, useState } from 'react';
import dispatch from '../../workers/dispatcher-main';
import Gpx from './Gpx';
import { TileKeyObject, Rectangle } from './types';

export interface GpxesProperties {
  keyObject?: TileKeyObject;
  zoom?: number;
  viewPort?: Rectangle;
}

export const Gpxes: react.FC<GpxesProperties> = (props: GpxesProperties) => {
  const [visibleGpxes, setVisibleGpxes] = useState<any>([]);
  useEffect(() => {
    const getVisibleGpxes = async () => {
      const gpxes = await dispatch({
        action: 'getGpxesForViewport',
        params: {
          viewport: props.viewPort,
          zoomLevel: props.keyObject?.zoomLevel,
        },
      });
      console.log(`Gpxes, visibles: ${JSON.stringify(gpxes)}`);
      startTransition(() => setVisibleGpxes(gpxes));
    };
    if (props.viewPort !== undefined) {
      getVisibleGpxes();
    }
  }, [
    props.viewPort?.bottomRight.x,
    props.viewPort?.bottomRight.y,
    props.viewPort?.topLeft.x,
    props.viewPort?.topLeft.y,
    props.keyObject?.zoomLevel,
  ]);
  return (
    <>
      {visibleGpxes.map((id: string) => (
        <Gpx
          key={id}
          id={id}
          keyObject={props.keyObject!}
          zoom={props.zoom!}
          viewPort={props.viewPort!}
        />
      ))}
    </>
  );
};

export default Gpxes;
